@@ -1,4 +1,4 @@
-/* gpgmetools.h - The GNU Privacy Assistant
+/* gpgmeedit.h - The GNU Privacy Assistant
  *      Copyright (C) 2002, Miguel Coca.
  *
  * This file is part of GPA
@@ -38,4 +38,8 @@ GpgmeError gpa_gpgme_edit_expire (GpgmeKey key, GDate *date);
 GpgmeError gpa_gpgme_edit_sign (GpgmeKey key, const gchar *private_key_fpr,
                                 gboolean local);
 
+/* Change the key's passphrase.
+ */
+GpgmeError gpa_gpgme_edit_passwd (GpgmeKey key);
+
 #endif
