@@ -376,8 +376,6 @@ key_gen_params_new(void)
   params->comment = NULL;
   params->expiryDate = NULL;
   params->interval = 0;
-  params->generate_revocation = FALSE;
-  params->send_to_server = FALSE;
   return params;
 }
 
@@ -530,6 +528,7 @@ const char * gpa_passphrase_cb (void *opaque, const char *desc, void **r_hd)
   GtkWidget * entry;
   GtkWidget * pixmap;
   GtkResponseType response;
+  gchar *passphrase;
 
   if (desc)
     {
@@ -561,22 +560,30 @@ const char * gpa_passphrase_cb (void *opaque, const char *desc, void **r_hd)
       /* Run the dialog */
       gtk_widget_show_all (dialog);
       response = gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_hide (dialog);
+      passphrase = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+      gtk_widget_destroy (dialog);
       if (response == GTK_RESPONSE_OK)
         {
-          return gtk_entry_get_text (GTK_ENTRY (entry));
+          *r_hd = passphrase;
+          return passphrase;
         }
       else
         {
           gpgme_cancel (ctx);
+          g_free (passphrase);
           return "";
         }
     }
+  else if (*r_hd)
+    {
+      /* Clean up */
+      passphrase = *r_hd;
+      g_free (passphrase);
+      *r_hd = NULL;
+      return NULL;
+    }
   else
     {
-      /* Free the dialog */
-      dialog = *r_hd;
-      gtk_widget_destroy (dialog);
       return NULL;
     }
 }
@@ -616,12 +623,21 @@ string_to_utf8 (const gchar *string)
 gchar *gpa_gpgme_key_get_userid (GpgmeKey key, int idx)
 {
   const char * uid;
+  gchar *uid_utf8;
 
   uid = gpgme_key_get_string_attr (key, GPGME_ATTR_USERID, NULL, idx);
-  return string_to_utf8 (uid);
+  uid_utf8 = string_to_utf8 (uid);
+  /* Tag revoked UID's*/
+  if (gpgme_key_get_ulong_attr (key, GPGME_ATTR_UID_REVOKED, NULL, idx))
+    {
+      gchar *tmp = g_strdup_printf ("[%s] %s", _("Revoked"), uid_utf8);
+      g_free (uid_utf8);
+      uid_utf8 = tmp;
+    }
+  return uid_utf8;
 }
 
-/* Return the key fingerprint, properly formatted according to the algorithm.
+/* Return the key fingerprint, properly formatted according to the key version.
  * Allocates a new string, which must be freed with g_free ().
  * This is based on code from GPAPA's extract_fingerprint.
  */
@@ -632,7 +648,7 @@ gchar *gpa_gpgme_key_get_fingerprint (GpgmeKey key, int idx)
   const char *fpraw = gpgme_key_get_string_attr (key, GPGME_ATTR_FPR,
 						 NULL, idx);
 
-  if (algorithm == 1 || algorithm == 2 ||algorithm == 3 )  /* RSA */
+  if (strlen (fpraw) == 32 )  /* v3 */
     {
       char *fp = g_malloc (strlen (fpraw) + 16 + 1);
       const char *r = fpraw;
