@@ -19,14 +19,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include "gpa.h"
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include "mischelp.h"
-#include "stringhelp.h"
-#include "gpa.h"
 #include "gpawindowkeeper.h"
 #include "gtktools.h"
 #include "icons.h"
@@ -42,8 +40,12 @@ static char *scroll_text[] =
   "Thomas Kster",
   "Peter Neuhaus",
   "Markus Gerwinski",
-  "Beate Esser"
+  "Beate Esser",
+  "Benedikt Wildenhain",
+  "Timo Schulz",
+  "Miguel Coca"
 };
+#define DIM(v)		     (sizeof(v)/sizeof((v)[0]))
 static int shuffle_array[ DIM(scroll_text) ];
 static int do_scrolling = 0;
 static int scroll_state = 0;
@@ -132,10 +134,11 @@ about_dialog_timer (gpointer data)
 			  scroll_area->allocation.width,
 			  scroll_area->allocation.height);
       gdk_draw_string (scroll_pixmap,
-		       scroll_area->style->font,
+		       gtk_style_get_font (scroll_area->style),
 		       scroll_area->style->black_gc,
 		       scroll_area->allocation.width - scroll_offset,
-		       scroll_area->style->font->ascent,
+		       scroll_area->allocation.height
+		        - gtk_style_get_font (scroll_area->style)->descent,
 		       scroll_text[cur_scroll_text]);
       gdk_draw_pixmap (scroll_area->window,
 		       scroll_area->style->black_gc,
@@ -147,8 +150,7 @@ about_dialog_timer (gpointer data)
       if (!scroll_state
 	  && scroll_offset > ((scroll_area->allocation.width
 			       + scroll_text_widths[cur_scroll_text])/2))
-	{
-	  scroll_state = 1;
+	{ scroll_state = 1;
 	  scroll_offset = (scroll_area->allocation.width
 			   + scroll_text_widths[cur_scroll_text])/2;
 	}
@@ -209,7 +211,13 @@ help_about (void)
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
-      label = gtk_label_new (_("brought to you by"));
+      label = gtk_label_new ("Copyright (C) 2000-2002 Miguel Coca,\n"
+                             "\t\t\t\t\t    G-N-U GmbH,\n"
+                             "\t\t\t\t\t    Intevation GmbH");
+      gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
+      gtk_widget_show (label);
+
+      label = gtk_label_new (_("Brought to you by:"));
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
@@ -223,13 +231,15 @@ help_about (void)
       gtk_container_add (GTK_CONTAINER (alignment), frame);
       gtk_widget_show (frame);
 
-      scroll_text_widths = xcalloc (DIM(scroll_text),
-				    sizeof *scroll_text_widths);
+      scroll_text_widths = g_malloc0 (DIM(scroll_text)*sizeof *scroll_text_widths);
+
+      gtk_widget_ensure_style (GTK_WIDGET (frame));
       max_width = 0;
       for (i = 0; i < DIM(scroll_text); i++)
 	{
-	  scroll_text_widths[i] = gdk_string_width (frame->style->font,
-						    scroll_text[i]);
+	  scroll_text_widths[i] =
+            gdk_string_width (gtk_style_get_font (frame->style),
+                              scroll_text[i]);
 	  if (scroll_text_widths[i] > max_width)
 	    max_width = scroll_text_widths[i];
 	}
@@ -237,13 +247,25 @@ help_about (void)
       scroll_area = gtk_drawing_area_new ();
       gtk_drawing_area_size (GTK_DRAWING_AREA (scroll_area),
 			     max_width + 10,
-			     frame->style->font->ascent
-			     + frame->style->font->descent );
+			     gtk_style_get_font (frame->style)->ascent
+			     + gtk_style_get_font (frame->style)->descent );
       gtk_widget_set_events (scroll_area, GDK_BUTTON_PRESS_MASK);
       gtk_container_add (GTK_CONTAINER (frame), scroll_area);
       gtk_widget_show (scroll_area);
 
-      label = gtk_label_new (_("See http://www.gnupg.org for news"));
+      label = gtk_label_new (_("GPA is free software under the"));
+      gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
+      gtk_widget_show (label);
+
+      label = gtk_label_new (_("GNU General Public License."));
+      gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
+      gtk_widget_show (label);
+
+      label = gtk_label_new (_("For news see:"));
+      gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
+      gtk_widget_show (label);
+
+      label = gtk_label_new (_("http://www.gnupg.org"));
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
@@ -317,7 +339,7 @@ help_license (gpointer param)
   GtkWidget *buttonClose;
 
   keeper = gpa_windowKeeper_new ();
-  windowLicense = gtk_window_new (GTK_WINDOW_DIALOG);
+  windowLicense = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gpa_windowKeeper_set_window (keeper, windowLicense);
   gtk_window_set_title (GTK_WINDOW (windowLicense),
 			_("GNU general public license"));
@@ -351,7 +373,7 @@ help_license (gpointer param)
 			     GTK_BUTTONBOX_END);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (hButtonBoxLicense), 10);
   gtk_container_set_border_width (GTK_CONTAINER (hButtonBoxLicense), 5);
-  paramClose = (gpointer *) xmalloc (2 * sizeof (gpointer));
+  paramClose = (gpointer *) g_malloc (2 * sizeof (gpointer));
   gpa_windowKeeper_add_param (keeper, paramClose);
   paramClose[0] = keeper;
   paramClose[1] = NULL;
@@ -366,76 +388,6 @@ help_license (gpointer param)
   gtk_main ();
 }
 
-static void
-help_warranty (gpointer param)
-{
-  GpaWindowKeeper *keeper;
-  GtkAccelGroup *accelGroup;
-  gpointer *paramClose;
-  GtkWidget *parent = param;
-
-  GtkWidget *windowLicense;
-  GtkWidget *vboxLicense;
-  GtkWidget *vboxGPL;
-  GtkWidget *labelJfdGPL;
-  GtkWidget *labelGPL;
-  GtkWidget *hboxGPL;
-  GtkWidget *textGPL;
-  GtkWidget *vscrollbarGPL;
-  GtkWidget *hButtonBoxLicense;
-  GtkWidget *buttonClose;
-
-  keeper = gpa_windowKeeper_new ();
-  windowLicense = gtk_window_new (GTK_WINDOW_DIALOG);
-  gpa_windowKeeper_set_window (keeper, windowLicense);
-  gtk_window_set_title (GTK_WINDOW (windowLicense),
-			_("GNU general public license"));
-  accelGroup = gtk_accel_group_new ();
-  gtk_window_add_accel_group (GTK_WINDOW (windowLicense), accelGroup);
-  gtk_signal_connect (GTK_OBJECT (windowLicense), "destroy",
-		      GTK_SIGNAL_FUNC (help_license_destroy), NULL);
-  
-  vboxLicense = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (vboxLicense), 5);
-  vboxGPL = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (vboxGPL), 5);
-  labelGPL = gtk_label_new ("");
-  labelJfdGPL = gpa_widget_hjustified_new (labelGPL, GTK_JUSTIFY_LEFT);
-  gtk_box_pack_start (GTK_BOX (vboxGPL), labelJfdGPL, FALSE, FALSE, 0);
-  hboxGPL = gtk_hbox_new (FALSE, 0);
-  textGPL = gtk_text_new (NULL, NULL);
-  gtk_text_set_editable (GTK_TEXT (textGPL), FALSE);
-  gtk_text_insert (GTK_TEXT (textGPL), NULL, &textGPL->style->black, NULL,
-		   gpa_license_text, -1);
-  gtk_editable_set_position(GTK_EDITABLE (textGPL), 15105);
-  gtk_widget_set_usize (textGPL, 500, 300);
-  gpa_connect_by_accelerator (GTK_LABEL (labelGPL), textGPL, accelGroup,
-			      _("_GNU general public license"));
-  gtk_box_pack_start (GTK_BOX (hboxGPL), textGPL, TRUE, TRUE, 0);
-  vscrollbarGPL = gtk_vscrollbar_new (GTK_TEXT (textGPL)->vadj);
-  gtk_box_pack_start (GTK_BOX (hboxGPL), vscrollbarGPL, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vboxGPL), hboxGPL, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vboxLicense), vboxGPL, TRUE, TRUE, 0);
-  hButtonBoxLicense = gtk_hbutton_box_new ();
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hButtonBoxLicense),
-			     GTK_BUTTONBOX_END);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hButtonBoxLicense), 10);
-  gtk_container_set_border_width (GTK_CONTAINER (hButtonBoxLicense), 5);
-  paramClose = (gpointer *) xmalloc (2 * sizeof (gpointer));
-  gpa_windowKeeper_add_param (keeper, paramClose);
-  paramClose[0] = keeper;
-  paramClose[1] = NULL;
-  buttonClose = gpa_buttonCancel_new (accelGroup, _("_Close"), paramClose);
-  gtk_container_add (GTK_CONTAINER (hButtonBoxLicense), buttonClose);
-  gtk_box_pack_start (GTK_BOX (vboxLicense), hButtonBoxLicense, FALSE, FALSE,
-		      0);
-  gtk_container_add (GTK_CONTAINER (windowLicense), vboxLicense);
-
-  gtk_window_set_modal (GTK_WINDOW (windowLicense), TRUE);
-  gpa_window_show_centered (windowLicense, parent);
-  gtk_main ();
-}				/* help_warranty */
-
 void
 help_help (void)
 {
@@ -448,10 +400,12 @@ gpa_help_menu_add_to_factory (GtkItemFactory *factory, GtkWidget * window)
 {
   GtkItemFactoryEntry menu[] = {
     {_("/_Help"), NULL, NULL, 0, "<Branch>"},
-    {_("/Help/_About"), NULL, help_about, 0, NULL},
-    {_("/Help/_License"), NULL, help_license, 0, NULL},
-    {_("/Help/_Warranty"), NULL, help_warranty, 0, NULL},
-    {_("/Help/_Help"), "F1", help_help, 0, NULL}
+#if 0  /* Help is not available yet. :-( */
+    {_("/Help/_Contents"), NULL, (GtkItemFactoryCallback)help_help, 0,
+     "<StockItem>", GTK_STOCK_HELP}
+#endif
+    {_("/Help/_License"), NULL, (GtkItemFactoryCallback)help_license, 0, NULL},
+    {_("/Help/_About"), NULL, (GtkItemFactoryCallback)help_about, 0, NULL}
   };
 
   gtk_item_factory_create_items (factory, sizeof (menu) / sizeof (menu[0]),
