@@ -22,12 +22,8 @@
 #define OWNERTRUSTDLG_H
 
 #include <gtk/gtk.h>
-#include <gpapa.h>
-
-gboolean
-gpa_ownertrust_run_dialog (GpapaPublicKey *key, GtkWidget *parent,
-			   GpapaOwnertrust * trust);
-
+#include <gpgme.h>
 
+gboolean gpa_ownertrust_run_dialog (GpgmeKey key, GtkWidget *parent);
 
 #endif /* OWNERTRUSTDLG_H */
